@@ -1,12 +1,12 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""Product class for the Zope 3 based product package
+"""TopologyIndex base class for the Zope 3 based ng.index.topology package
 
-$Id: topologybase.py 52764 2009-03-31 14:19:49Z cray $
+$Id: topologybase.py 53601 2009-08-15 21:50:58Z cray $
 """
-__author__  = ""
+__author__  = "Andrey Orlov, 2009"
 __license__ = "GPL"
-__version__ = "$Revision: 52764 $"
+__version__ = "$Revision: 53601 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
