@@ -1,12 +1,12 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""Product class for the Zope 3 based product package
+"""Item of topology index container. Each item correspond to node of graph topology relation.
 
-$Id: topologyitem.py 52787 2009-04-01 08:15:02Z cray $
+$Id: topologyitem.py 53601 2009-08-15 21:50:58Z cray $
 """
-__author__  = ""
+__author__  = "Andrey Orlov, 2009"
 __license__ = "GPL"
-__version__ = "$Revision: 52787 $"
+__version__ = "$Revision: 53601 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
